# DALi Introduction

### Introduction
 + [What is DALi?](@ref dali-introduction)
 + [Features](@ref dali-features)
 + [High Level Design](@ref dali-hld)
  + [Components](@ref dali-components)
  + [Main, Update & Render Threads](@ref dali-threads)
 + [DALi Fundamentals](@ref fundamentals)
  + [Actors & Stage](@ref actors-and-stage)
  + [Coordinate System](@ref coordinate-system)
  + Units & the Default Camera (default unit 1 is 1 pixel with default camera)
  + [Handle / Body Idiom](@ref handle-body-idiom)
  + Signals
  + [Properties](@ref properties)
  + Actions
 + Tutorial
  + [Hello World](@ref hello-world)

### Getting Started
 + How to build DALi on Ubuntu Desktop

### Programming Guide
 + [Programming Languages:](@ref programming-languages)
  + [C++](@ref c-plus-plus)
  + [JavaScript](@ref java-script-support)
  + [JSON](@ref json-support)
 + [Application](@ref dali-application)
 + Actors
  + [Positioning](@ref positioning-actors)
  + [Event Handling](@ref event-system)
  + [Layouting](@ref size-negotiation)
  + [Image Actor](@ref image-actor)
 + Animation
  + AnimateTo
  + AnimateBy
  + Key Frame Animations
  + Path Animations
  + [Constraints](@ref constraints)
   + Equal To Constraint
   + Relative To Constraint
   + Linear Constrainer
   + Path Constrainer
  + [Multi-threading Notes](@ref animation-multi-threading-notes)
  + [Shader Animation](@ref animation-shader)
  + [Example and Usage](@ref animation-example)
  + [Rotation with quaternions](@ref animation-rotation)

### Resources
 + Resource Image
 + 9 Patch Image
 + Buffer Image

### Control Base Class
 + [Background Feature](@ref background)
 + Keyboard Focus
 + Accessibility

### UI Controls
 + [Text Label](@ref text-label)
 + [Text Field](@ref text-field)
 + Buttons
 + TableView
 + [Scroll View](@ref scroll-view)
 + ItemView

### RenderTasks

### Shader Effects
 + [Overview](@ref shader-intro)

### Scripting
 + [JSON and JavaScript Overview](@ref scriptoverview)
 + [JSON Syntax](@ref script-json-specification)
 + [Scripting Hello World](@ref script-hello)

### Tools
 + Environment Variables
 + [Resource Tracking](@ref resourcetracking)
 + Logging
 + GUI Builder
 + [Stagehand - DALi Visual Debugger](@ref stagehand)

### Viewing Modes
 + [Overview](@ref viewing-modes)

### Extending DALi
 + Control Base Class Services
 + How to write Custom UI Controls
  + [Size Negotiation for Controls](@ref size-negotiation-controls)
  + [Type Registration](@ref type-registration)
  + How to make Controls Scriptable
 + [Automated Tests](@ref auto_testing)
 + [Programming Guide](@ref documentationguide)
 + [JavaScript Wrapping Guide for DALi developers](@ref javascriptwrapping)

### Application Optimization Guide
 + [Texture Atlases](@ref textureatlases)
 + [Texture Compression](@ref texturecompression)
 + Performance & Debugging
 + [Performance Tips](@ref performancetips)
 + [Performance Profiling](@ref performanceprofiling)

